/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER, TCSDESIGNER
 * Version: 2.0
 */

using System;
using System.Web.UI;

namespace TopCoder.Web.UI.WebControl.BreadCrumb
{
    /// <summary>
    /// This interface defines the contract for classes wishing to discover the current node. The implementation should
    /// discover, in its own way, the current node when <see cref="GetCurrentNode"/> is called and return the node
    /// representation of that url.
    /// </summary>
    /// <remarks>
    /// Implementations of this class will be created in the <see cref="BreadCrumbTrailControl.RenderContents"/> via
    /// the object factory and will be called to determine the current node. The node representation of the current URL
    /// (plus sorted query strings) will then be returned by the implementing class and used to discover the path to
    /// the root. Implementations should be thread safe in the context of the rendering process.
    /// </remarks>
    public interface INodeDiscovery
    {
        /// <summary>
        /// Called to retrieve the node representation of the current page/title. If the current page could not be
        /// found or is not applicable - simply return null. The returned node should include any query strings (sorted
        /// in ascending order) available in the <see cref="BreadCrumbNode.Url"/> attribute. Please note that the title
        /// passed can be null if the title should be picked up from the site map instead.
        /// </summary>
        /// <param name="title">A possibly null, possibly empty (trimmed) title to use.</param>
        /// <param name="page">A non-null page to use.</param>
        /// <exception cref="ArgumentNullException">If <paramref name="page"/> is null.</exception>
        /// <exception cref="BreadCrumbException">For any exception while discovering the page.</exception>
        /// <returns>A node representing the current URL.</returns>
        BreadCrumbNode GetCurrentNode(string title, Page page);
    }
}
