/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER, TCSDESIGNER
 * Version: 2.0
 */

using System;
using System.Web.UI;

namespace TopCoder.Web.UI.WebControl.BreadCrumb
{
    /// <summary>
    /// This interface defines the contract for classes wishing to write out the path discovered. Implementations of
    /// this interface will be called with a writer, the path to write and the bread crumb trail control itself. The
    /// implementation is then responsible for formatting the path in its own way - writing the path out to the
    /// <see cref="HtmlTextWriter"/>.
    /// </summary>
    /// <remarks>
    /// Implementations of this class will be created in the <see cref="BreadCrumbTrailControl.RenderContents"/> method
    /// via the object factory, when the path should be written. The implementation is then responsible for writing the
    /// path out to the specified writer. Implementations should be thread safe in the context of the rendering
    /// process.
    /// </remarks>
    public interface IPathWriter
    {
        /// <summary>
        /// Called by <see cref="BreadCrumbTrailControl"/> to write out the specified path using the specified
        /// <see cref="HtmlTextWriter"/> and the attributes specified in the passed bread crumb trail control.
        /// </summary>
        /// <remarks>
        /// Any exceptions encountered should be returned from this method depending on the setting of the
        /// <see cref="ErrorDisposition"/>:
        /// <list>
        /// <item>Silently ignore - the method should always return null.</item>
        /// <item>Throw exception - the method should stop processing immediately when an exception is encountered and
        /// that exception should be returned (thus a length 1 array).</item>
        /// <item>Render exception - the method should attempt to process as much as it can and return all exceptions
        /// that it encounters (the BreadCrumbTrailControl will do the actual exception rendering).
        /// </item>
        /// </list>
        /// </remarks>
        /// <param name="writer">A non-null writer to use.</param>
        /// <param name="nodes">The non-null, non-empty array of nodes to write.</param>
        /// <param name="parent">A non-null parent bread crumb trail control to get attributes from.</param>
        /// <exception cref="ArgumentNullException">If <paramref name="writer"/>, <paramref name="nodes"/> or
        /// <paramref name="parent"/> is null.</exception>
        /// <exception cref="ArgumentException">If <paramref name="nodes"/> is empty or contains elements with a null
        /// URL.
        /// </exception>
        /// <returns>null if no exceptions occur or a >= 1 length array of exceptions that occurred.</returns>
        BreadCrumbException[] WritePath(HtmlTextWriter writer, BreadCrumbNode[] nodes, BreadCrumbTrailControl parent);
    }
}
