/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER, TCSDESIGNER
 * Version: 2.0
 */

using System.Collections;

namespace TopCoder.Web.UI.WebControl.BreadCrumb.PathDiscovery
{
    /// <summary>
    /// Defines the contract for a data source for the site. Implementations of this interface should create and return
    /// a site map (in an <see cref="IDictionary"/> implementation) consisting of <see cref="INodeMatcher"/> nodes that
    /// describe the site map.
    /// </summary>
    /// <remarks>
    /// The returned <c>IDictionary</c> should have each unique <c>INodeMatcher</c> listed as the key and an
    /// <c>IList</c> of <c>INodeMatcher</c> nodes that describe the children of that key. Implementations of this
    /// interface should be thread safe.
    /// </remarks>
    public interface ISiteDiscovery
    {
        /// <summary>
        /// Returns an <see cref="IDictionary"/> implementation with <see cref="NodeMatcher"/> keys and an
        /// <see cref="IList"/> of <see cref="INodeMatcher"/> elements as the value. The key <c>INodeMatcher</c>
        /// represents the parent and the value (the list) represents the child values. The value can be null or an
        /// empty list to represent no child elements (i.e. it's a leaf node).
        /// </summary>
        /// <exception cref="BreadCrumbException">Any error.</exception>
        /// <returns>A site map.</returns>
        IDictionary GetSiteMap();
    }
}
