/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER
 * Version: 2.0
 */

using NUnit.Framework;

namespace TopCoder.Web.UI.WebControl.BreadCrumb.NodeDiscovery
{
    /// <summary>
    /// This class tests the node discovery class for HTTP requests.
    /// </summary>
    [TestFixture]
    public class HttpTestHttpRequestNodeDiscovery : HttpTest
    {
        /// <summary>
        /// Tests a plain call to a test page that writes the URL in unencoded HTML.
        /// </summary>
        [Test]
        public void TestSimpleURL()
        {
            Browser.GetPage(@"http://localhost/HttpRequestNode.aspx");

            VerifyString("/HttpRequestNode.aspx");
        }

        /// <summary>
        /// Tests a call to a test page that writes the URL in unencoded HTML. The URL itself contains percent-sign
        /// encoding.
        /// </summary>
        [Test]
        public void TestEncodedURL()
        {
            Browser.GetPage(@"http://localhost/%48ttpRequestNode.aspx");

            VerifyString("/HttpRequestNode.aspx");
        }

        /// <summary>
        /// Tests a call to a test page that writes the URL in unencoded HTML. This time with a query string, that's
        /// already sorted.
        /// </summary>
        [Test]
        public void TestSimpleQueryString()
        {
            Browser.GetPage(@"http://localhost/%48ttpRequestNode.aspx?A=b&B=c");

            VerifyString("/HttpRequestNode.aspx?A=b&B=c");
        }

        /// <summary>
        /// Tests a call to a test page that writes the URL in unencoded HTML. This time with a query string, that's
        /// not sorted.
        /// </summary>
        [Test]
        public void TestUnsortedQueryString()
        {
            Browser.GetPage(@"http://localhost/%48ttpRequestNode.aspx?B=c&A=b");

            VerifyString("/HttpRequestNode.aspx?A=b&B=c");
        }

        /// <summary>
        /// Tests a call to a test page that writes the URL in unencoded HTML. This time with a query string, with no
        /// real content!
        /// </summary>
        [Test]
        public void TestEmptyQueryString()
        {
            Browser.GetPage(@"http://localhost/%48ttpRequestNode.aspx?");

            VerifyString("/HttpRequestNode.aspx");
        }
    }
}
