/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER
 * Version: 2.0
 */

using NUnit.Framework;

namespace TopCoder.Web.UI.WebControl.BreadCrumb.PathDiscovery
{
    /// <summary>
    /// This class tests the static (XML) path discovery class.
    /// </summary>
    [TestFixture]
    public class HttpTestXmlPathDiscovery : HttpTest
    {
        /// <summary>
        /// We move around between different pages, how we get to a specific child should NOT affect the trail.
        /// </summary>
        /// <remarks>
        /// We keep this in a single test case to create the desired trail.
        /// </remarks>
        [Test]
        public void TestWandering()
        {
            Browser.GetPage(@"http://localhost/?unknown");
            VerifyString(@"<span id=""bcc""></span>");

            Browser.GetPage(@"http://localhost/?main");
            VerifyString(@"<span id=""bcc""><a href=""/Default.aspx?=main"">Main</a></span>");

            Browser.GetPage(@"http://localhost/?child1");
            VerifyString(@"<span id=""bcc""><a href=""/"">Main</a><span>:</span><a href=""/Default.aspx?=child1"">" +
                @"Child1</a></span>");

            Browser.GetPage(@"http://localhost/?childFolder");
            VerifyString(@"<span id=""bcc""><a href=""/Other"">Alternative root2</a><span>:</span>" +
                @"<a href=""/Default.aspx?=childFolder"">ChildFolder</a></span>");

            Browser.GetPage(@"http://localhost/?child3");
            VerifyString(@"<span id=""bcc""><a href=""/Other"">Alternative root2</a><span>:</span>" +
                @"<a href=""/childFolder/"">ChildFolder</a><span>:</span><a href=""/Default.aspx?=child3"">Child3" +
                @"</a></span>");

            // Go to a page which doesn't exist
            Browser.GetPage(@"http://localhost/?child5");
            VerifyString(@"<span id=""bcc""></span>");

            Browser.GetPage(@"http://localhost/?child4");
            VerifyString(@"<span id=""bcc""><a href=""/Other"">Alternative root2</a><span>:</span>" +
                @"<a href=""/childFolder/"">ChildFolder</a><span>:</span><a href=""/Default.aspx?=child4"">Child4" +
                @"</a></span>");

            // Go up along the existing path
            Browser.GetPage(@"http://localhost/?childFolder");
            VerifyString(@"<span id=""bcc""><a href=""/Other"">Alternative root2</a><span>:</span>" +
                @"<a href=""/Default.aspx?=childFolder"">ChildFolder</a></span>");

            Browser.GetPage(@"http://localhost/?child4");
            VerifyString(@"<span id=""bcc""><a href=""/Other"">Alternative root2</a><span>:</span>" +
                @"<a href=""/childFolder/"">ChildFolder</a><span>:</span><a href=""/Default.aspx?=child4"">" +
                @"Child4</a></span>");

            Browser.GetPage(@"http://localhost/?child2");
            VerifyString(@"<span id=""bcc""><a href=""/"">Main</a><span>:</span><a href=""/Default.aspx?=child2"">" +
                @"Child2</a></span>");

            Browser.GetPage(@"http://localhost/?other");
            VerifyString(@"<span id=""bcc""><a href=""/Default.aspx?=other"">Alternative root</a></span>");

            Browser.GetPage(@"http://localhost/?childFolder");
            VerifyString(@"<span id=""bcc""><a href=""/Other"">Alternative root2</a><span>:</span>" +
                @"<a href=""/Default.aspx?=childFolder"">ChildFolder</a></span>");

            Browser.GetPage(@"http://localhost/?Other");
            VerifyString(@"<span id=""bcc""><a href=""/Default.aspx?=Other"">Alternative root2</a></span>");

            Browser.GetPage(@"http://localhost/?childFolder");
            VerifyString(@"<span id=""bcc""><a href=""/Other"">Alternative root2</a><span>:</span>" +
                @"<a href=""/Default.aspx?=childFolder"">ChildFolder</a></span>");

            // Drill down to a completely different node again
            Browser.GetPage(@"http://localhost/?child2");
            VerifyString(@"<span id=""bcc""><a href=""/"">Main</a><span>:</span><a href=""/Default.aspx?=child2"">" +
                @"Child2</a></span>");
        }
    }
}
