/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER
 * Version: 2.0
 */

using System;
using NUnit.Framework;
using TopCoder.Web.UI.WebControl.BreadCrumb.PathDiscovery.NodeMatcher;

namespace TopCoder.Web.UI.WebControl.BreadCrumb.PathDiscovery
{
    /// <summary>
    /// This class tests the internal node pair helper class, used in shortest path searches and when persisting the
    /// current path in a session.
    /// </summary>
    [TestFixture]
    public class TestNodePair
    {
        /// <summary>
        /// A test object array.
        /// </summary>
        private NodePair[] testObjects = new NodePair[2];

        /// <summary>
        /// The test matcher.
        /// </summary>
        private INodeMatcher testMatcher;

        /// <summary>
        /// A test node.
        /// </summary>
        private BreadCrumbNode testNode;

        /// <summary>
        /// Sets up the test objects, one through deserialization.
        /// </summary>
        [SetUp]
        public void Setup()
        {
            testMatcher = new RegexNodeMatcher("title", "url", "/");
            testNode = new BreadCrumbNode("title", "url");
            testObjects[0] = new NodePair(testNode, testMatcher);
            testObjects[1] = (NodePair) Helper.DeSerialize(testObjects[0]);
        }

        /// <summary>
        /// Tests the node readonly property.
        /// </summary>
        [Test]
        public void TestNode()
        {
            foreach (NodePair pair in testObjects)
            {
                Assert.AreEqual(testNode, pair.Node, "Simple pair equality match.");
            }
        }

        /// <summary>
        /// Tests the node readonly property when title and/or nodematcher are null.
        /// </summary>
        [Test]
        public void TestNodeNulls()
        {
            BreadCrumbNode nullTitleNode = new BreadCrumbNode(null, testNode.Url);
            Assert.AreEqual(testNode, new NodePair(nullTitleNode, testMatcher).Node,
                "Even with a null title, the node matcher should give the title.");

            Assert.AreEqual(testNode, new NodePair(testNode, null).Node,
                "With a normal node and a null matcher, everything is fine.");

            Assert.AreEqual(nullTitleNode, new NodePair(nullTitleNode, null).Node,
                "A null title is returned if there is no title and no matcher.");
        }

        /// <summary>
        /// Tests the node matcher.
        /// </summary>
        [Test]
        public void TestNodeMatcher()
        {
            foreach (NodePair pair in testObjects)
            {
                Assert.AreEqual(testMatcher, pair.NodeMatcher, "Node matcher should match.");
            }

            NodePair newPair = new NodePair(testNode, null);
            Assert.IsNull(newPair.NodeMatcher, "The node matcher should be null.");
        }

        /// <summary>
        /// Null URLs are not allowed in the node in the constructor (that's only possible if the default constructor
        /// for nodes has been used). This is treated like a null argument when the exception is thrown.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void TestNodeNullConstructor()
        {
            new NodePair(new BreadCrumbNode(), testMatcher);
        }
    }
}
